pub struct GizmoConfigStore { /* private fields */ }Expand description
A Resource storing GizmoConfig and GizmoConfigGroup structs
Use app.init_gizmo_group::<T>() to register a custom config group.
Implementations
Sourceimpl GizmoConfigStore
impl GizmoConfigStore
Sourcepub fn get_config_dyn(
&self,
config_type_id: &TypeId,
) -> Option<(&GizmoConfig, &dyn Reflect)>
pub fn get_config_dyn( &self, config_type_id: &TypeId, ) -> Option<(&GizmoConfig, &dyn Reflect)>
Returns GizmoConfig and GizmoConfigGroup associated with TypeId of a GizmoConfigGroup
Sourcepub fn config<T: GizmoConfigGroup>(&self) -> (&GizmoConfig, &T)
pub fn config<T: GizmoConfigGroup>(&self) -> (&GizmoConfig, &T)
Returns GizmoConfig and GizmoConfigGroup associated with GizmoConfigGroup T
Panics
If the config does not exist for GizmoConfigGroup T
For a non-panicking version, see get_config.
Sourcepub fn get_config<T: GizmoConfigGroup>(&self) -> Option<(&GizmoConfig, &T)>
pub fn get_config<T: GizmoConfigGroup>(&self) -> Option<(&GizmoConfig, &T)>
Returns Some(GizmoConfig and GizmoConfigGroup associated with GizmoConfigGroup T if they exist,
else None.
If the configs will always be present, use config.
Sourcepub fn get_config_mut_dyn(
&mut self,
config_type_id: &TypeId,
) -> Option<(&mut GizmoConfig, &mut dyn Reflect)>
pub fn get_config_mut_dyn( &mut self, config_type_id: &TypeId, ) -> Option<(&mut GizmoConfig, &mut dyn Reflect)>
Returns mutable GizmoConfig and GizmoConfigGroup associated with TypeId of a GizmoConfigGroup
Sourcepub fn config_mut<T: GizmoConfigGroup>(&mut self) -> (&mut GizmoConfig, &mut T)
pub fn config_mut<T: GizmoConfigGroup>(&mut self) -> (&mut GizmoConfig, &mut T)
Returns mutable GizmoConfig and GizmoConfigGroup associated with GizmoConfigGroup T
Panics
If the config does not exist for GizmoConfigGroup T
For a non-panicking version, see get_config_mut.
Sourcepub fn get_config_mut<T: GizmoConfigGroup>(
&mut self,
) -> Option<(&mut GizmoConfig, &mut T)>
pub fn get_config_mut<T: GizmoConfigGroup>( &mut self, ) -> Option<(&mut GizmoConfig, &mut T)>
Returns mutable Some(GizmoConfig and GizmoConfigGroup) associated with GizmoConfigGroup T if they exist,
else None
If the configs will always be present, use config_mut.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (&TypeId, &GizmoConfig, &dyn Reflect)> + '_
pub fn iter( &self, ) -> impl Iterator<Item = (&TypeId, &GizmoConfig, &dyn Reflect)> + '_
Returns an iterator over all GizmoConfigs.
Sourcepub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (&TypeId, &mut GizmoConfig, &mut dyn Reflect)> + '_
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (&TypeId, &mut GizmoConfig, &mut dyn Reflect)> + '_
Returns an iterator over all GizmoConfigs, by mutable reference.
Sourcepub fn insert<T: GizmoConfigGroup>(
&mut self,
config: GizmoConfig,
ext_config: T,
)
pub fn insert<T: GizmoConfigGroup>( &mut self, config: GizmoConfig, ext_config: T, )
Inserts GizmoConfig and GizmoConfigGroup replacing old values